Learn R Programming

SHELF (version 1.9.0)

elicitQuartiles: Elicit judgements and fit distributions interactively using the quartile method

Description

Opens up a web browser (using the shiny package), from which you can specify the quartiles, fit distributions and plot the fitted density functions with additional feedback.

Usage

elicitQuartiles()

Arguments

Value

An object of class elicitation, which is returned once the Finish button has been clicked. See fitdist for details.

Author

Jeremy Oakley <j.oakley@sheffield.ac.uk>

Details

Parameter limits determine which distributions can be fitted. Finite lower limits are needed for the gamma, lognormal and log-t distributions, and both limits must be finite for to fit a beta distribution. If a histogram is fitted without specifying finite limits, endpoints are chosen based on fitting a normal distribution.

Click the Finish button to quit the elicitation session.

Examples

Run this code

if (FALSE) {

elicitQuartiles()

}

Run the code above in your browser using DataLab