elicitSHELF: SHELF Elicitation

View source: R/elicitSHELF.R

elicitSHELFR Documentation

SHELF Elicitation

Description

Opens up a web browser in which you can implement the general SHELF protocol of individual elicitation followed by group discussion and elicitation of a single set of Rational Impartial Observer (RIO) probabilities

Usage

elicitSHELF()

Author(s)

Jeremy Oakley <j.oakley@sheffield.ac.uk>

Examples


## Not run: 


elicitSHELF()


## End(Not run)

SHELF documentation built on April 4, 2026, 9:07 a.m.