Learn R Programming

SHELF (version 1.0.1)

roulette: Elicit one set of probabilities using the roulette method.

Description

Produces a graphics window with the roulette grid. The user clicks in the window to allocate 'chips' to 'bins'. The elicited probability inside each bin is the proportion of chips in each bin.

Usage

roulette(lower=0, upper=100, gridheight=10, nbins=10, round.end = F)

Arguments

lower
The lower limit on the x-axis of the roulette grid.
upper
The upper limit on the x-axis of the roulette grid.
gridheight
The maximum number of chips that can be allocated to a single bin.
nbins
The number of equally sized bins drawn between Lo and Up.
round.end
If set to T, empty bins and the uppermost non-empty bin will be ignored. For example, with 20 chips in total, if the uppermost non-empty bin is [70,80] and contains 1 chip, setting round.end = F will result in an elicited probabi

Value

  • A list, with outputs $v corresponding to the upper limits of each bin, and $p corresponding to cumulative probabilities for each upper bin limit.

See Also

elicit, feedback, fitdist, plinearpool, plotfit, qlinearpool

Examples

Run this code
x<-roulette()
# Then allocate chips to bins

# To fit distributions and see the results
myfit <- fitdist(vals = x$v, probs = x$p)
plotfit(myfit)

Run the code above in your browser using DataLab