| elicitSHELF | R Documentation |
Opens up a web browser in which you can implement the general SHELF protocol of individual elicitation followed by group discussion and elicitation of a single set of Rational Impartial Observer (RIO) probabilities
elicitSHELF()
Jeremy Oakley <j.oakley@sheffield.ac.uk>
## Not run:
elicitSHELF()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.